@@ -2,7 +2,7 @@
 Dot-access for Python dictionaries and more
 """
 
-__version__ = '3.0.1'
+__version__ = '3.0.2'
 
 from json import loads as json_loads
 from json import load as json_load
@@ -13,11 +13,9 @@ from .types import classify, ClassyDict
 def loads(*args, **kwargs):
     """Override loads function"""
 
-    _data = json_loads(*args, **kwargs)
-    return classify(_data)
+    return classify(json_loads(*args, **kwargs))
 
 def load(*args, **kwargs):
     """Override load function"""
 
-    _data = json_load(*args, **kwargs)
-    return classify(_data)
+    return classify(json_load(*args, **kwargs))
